summaryrefslogtreecommitdiffstats
path: root/video/out/opengl/context.c
diff options
context:
space:
mode:
Diffstat (limited to 'video/out/opengl/context.c')
-rw-r--r--video/out/opengl/context.c10
1 files changed, 2 insertions, 8 deletions
diff --git a/video/out/opengl/context.c b/video/out/opengl/context.c
index c491039b66..c9f8445246 100644
--- a/video/out/opengl/context.c
+++ b/video/out/opengl/context.c
@@ -21,15 +21,9 @@
#include "utils.h"
// 0-terminated list of desktop GL versions a backend should try to
-// initialize. The first entry is the most preferred version.
-const int mpgl_preferred_gl_versions[] = {
- 440,
- 430,
- 400,
- 330,
+// initialize. Each entry is the minimum required version.
+const int mpgl_min_required_gl_versions[] = {
320,
- 310,
- 300,
210,
0
};